@@ -446,7 +446,7 @@ def create_geo_classes(geo_types):
     class GeometricVolume(geo_types['volume']):
 
         def __init__(self, *args, **kwargs):
-            BaseGeometricVolume.__init__(self, *args, **kwargs)
+            geo_types['volume'].__init__(self, *args, **kwargs)
             self._faces = kwargs.get('faces', None)
 
         @property
