@@ -368,6 +368,10 @@ class TemplateParser(object):
     def get_geo_components(self, geometry):
         return Enumerable.ToList[Component](self.current_data_model.exch.GetComponents(geometry))
 
+    def get_py_geo_components(self, geometry, template_name=None):
+        components = Enumerable.ToList[Component](self.current_data_model.exch.GetComponents(geometry))
+        return [self.create_python_object(x, template_name=template_name) for x in components]
+
 
 def add_properties(prop, type):
     """
