@@ -1,5 +1,14 @@
-from .template_tools import Template
-from .config import yaml
+
+# from .config import yaml
+
+
+class classproperty(object):
+
+    def __init__(self, getter):
+        self.getter = getter
+
+    def __get__(self, instance, owner):
+        return self.getter(owner)
 
 
 class SimultanComponent(object):
@@ -69,6 +78,8 @@ class SimultanComponent(object):
 
 def create_example_template():
 
+    from .template_tools import Template
+
     material_template = Template(template_name='Material',
                                  template_id='1',
                                  content=['c', 'w20', 'w80', 'lambda', 'mu', 'rho'],
@@ -116,6 +127,8 @@ def create_example_template():
 
 def create_example_template_bim_bestand_network():
 
+    from .template_tools import Template
+
     component_template = Template(template_name='Component',
                                   template_id=1,
                                   content=['AKS-Id', 'Loss Factor'],
@@ -214,32 +227,7 @@ def create_example_simultan_components(templates, flat_list_components):
     return simultan_components
 
 
-if __name__ == '__main__':
-
-    # create example templates
-    # templates = create_example_template()
-    templates = create_example_template_bim_bestand_network()
-
-    # write the example templates to a file:
-    with open('example_templates.yml', mode='w') as f_obj:
-        yaml.dump(templates, f_obj)
-
-    # load the example templates:
-    templates = load_templates('example_templates.yml')
-
-    # create classes from the templates:
-    template_classes = create_template_classes(templates)
-
-    simultan_components = create_example_simultan_components(templates, n=5)
-    simultan_components = class_type_simultan_components(simultan_components, template_classes)
+def get_obj_by_id(cls, id):
+    return cls._cls_instances_dict.get(id, None)
 
 
-    # the simultan components are now of the type which is defined in the templates
-    print(simultan_components)
-
-    # the class typed components still keep all methods and attributes from simultan:
-    print(simultan_components[0].simultan_method())
-
-    # and the class typed components have the new defined method python_spec_func:
-    simultan_components[10].python_spec_func()
-
